@@ -15,21 +15,21 @@ class LogAdmin(admin.ModelAdmin):
 
 class LoginAttemptAdmin(admin.ModelAdmin):
     model = m.LoginAttempt
-    
+
     list_display = ('username', 'count', 'timestamp', 'activate')
     list_display_links = None
-    
+
     def activate(self, obj):
         UserModel = get_user_model()
         try:
             user = UserModel._default_manager.get_by_natural_key(obj.username)
             if user.is_active:
                 return "Active"
-            activation_url = reverse("useraudit:reactivate_user", args=[user.id,])
+            activation_url = reverse("useraudit:reactivate_user", args=[user.id])
             return "<a href='%s'>Activate</a>" % activation_url
         except UserModel.DoesNotExist:
             return "N/A"
-    
+
     activate.short_description = "Status"
     activate.allow_tags = True
 
